package cn.iocoder.yudao.module.remote.service.robot;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.module.remote.controller.admin.robot.dto.PositionMapRespDTO;
import cn.iocoder.yudao.module.remote.controller.admin.robot.dto.RemoteRobotChangeModeDTO;
import cn.iocoder.yudao.module.remote.util.IpUtils;
import cn.iocoder.yudao.module.system.api.remote.RemoteRobotApi;
import cn.iocoder.yudao.module.system.api.remote.dto.RemoteRobotDTO;
import cn.iocoder.yudao.module.system.api.remote.dto.RemoteRobotStatusDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception0;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.PATH_PLANNING_NOT_EXISTS;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.TASK_COMMONG_FAIL;

@Slf4j
@Service
public class RemoteRobotServiceImpl implements RemoteRobotService{

    @Resource
    private RemoteRobotApi remoteRobotApi;

    /**
     * 获取地图区域对应的机器人信息
     * @param positionMapRespDTO
     * @return
     */
    @Override
    public List<RemoteRobotDTO> remoteGetAreaRobot(PositionMapRespDTO positionMapRespDTO) {
        return remoteRobotApi.remoteGetAreaRobot(positionMapRespDTO.getId());
    }

    /**
     * 一键急停or一键恢复地图上所有AGV
     * @param id
     * @param type
     */
    @Override
    public void remoteEmergencyStopOrRecovery(Long id, Integer type) {
        CommonResult<Boolean> result = remoteRobotApi.remoteEmergencyStopOrRecovery(id,type);
        if (!result.isSuccess()){
            throw exception0(TASK_COMMONG_FAIL.getCode(), result.getMsg());
        }
    }

    /**
     * 获取机器人远遥模式/急停/协控状态
     * @param request
     * @return
     */
    @Override
    public RemoteRobotStatusDTO getRemoteRobotStatus(HttpServletRequest request) {
        String ip = IpUtils.getIp(request);
        return remoteRobotApi.getRemoteRobotStatus(ip);
    }

    /**
     * 暂停机器人
     * @param robotNo
     * @return
     */
    @Override
    public void robotStop(String robotNo) {
        CommonResult<Boolean> result = remoteRobotApi.robotStop(robotNo);
        if (!result.isSuccess()){
            throw exception0(TASK_COMMONG_FAIL.getCode(), result.getMsg());
        }
    }

    /**
     * 恢复车辆
     * @param robotNo
     */
    @Override
    public void recovery(String robotNo) {
        CommonResult<Boolean> result = remoteRobotApi.recovery(robotNo);
        if (!result.isSuccess()){
            throw exception0(TASK_COMMONG_FAIL.getCode(), result.getMsg());
        }
    }

    /**
     * 切换远遥模式
     * @param data
     * @return
     */
    @Override
    public void robotChangeMode(RemoteRobotChangeModeDTO data,HttpServletRequest request) {
        String ip = IpUtils.getIp(request);
        CommonResult<Boolean> result = remoteRobotApi.robotChangeMode(data.getRemoteMode(), ip, data.getRobotNo());
        if (!result.isSuccess()){
            throw exception0(TASK_COMMONG_FAIL.getCode(), result.getMsg());
        }
    }

    @Override
    public Object getPositionMapList() {
        return remoteRobotApi.getRemotePositionMapList();
    }
}
