package cn.iocoder.yudao.module.system.controller.admin.robot.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import lombok.*;
import io.swagger.v3.oas.annotations.media.Schema;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import org.springframework.format.annotation.DateTimeFormat;
import java.time.LocalDateTime;

import static cn.iocoder.yudao.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;

@Schema(description = "管理后台 - 机器人任务明细分页 Request VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class RobotTaskDetailPageReqVO extends PageParam {

    @Schema(description = "机器人任务主表id", example = "9241")
    private Long robotTaskId;

    @Schema(description = "任务类型（1：取放货、2：停车、 3：充电、4：移动、5：仅取货、6：仅放货、7：扫描码、8：检测托盘类型）", example = "2")
    private Integer taskType;

    @Schema(description = "放货类型（1：库位、2：线库、 3：区域）", example = "2")
    private Integer releaseType;

    @Schema(description = "取货类型（1：库位、2：线库、 3：区域）", example = "1")
    private Integer takeType;

    @Schema(description = "放货库位/线库/区域", example = "6223")
    private Long releaseId;

    @Schema(description = "取货库位/线库/区域", example = "24801")
    private Long takeId;

    @Schema(description = "计算后的来源库位编号")
    private String fromLocationNo;
    @Schema(description = "计算后的来源库位id")
    private Long fromLocationId;
    @Schema(description = "计算后的目标库位编号")
    private String toLocationNo;
    @Schema(description = "计算后的目标库位id")
    private Long toLocationId;

    @Schema(description = "AGV编号")
    private String robotNo;

    @Schema(description = "AGV动作")
    private String robotAction;
    @Schema(description = "取货线库id")
    private Long fromLaneId;

    @Schema(description = "放货线库id")
    private Long toLaneId;

    @Schema(description = "任务状态(0:未开始、1：执行中、2：已完成、3：已取消、4:异常)", example = "1")
    private Integer taskStatus;

    @Schema(description = "任务阶段(0:待执行、1：前往取货、2：取货中、3：前往放货、4：放货中、5：结束、6：移动中、7:正在充电、8:取消、9:人工完成、10:异常)")
    private Long taskStage;

    @Schema(description = "开始时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private LocalDateTime[] startTime;

    @Schema(description = "结束时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private LocalDateTime[] endTime;

    @Schema(description = "创建时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private LocalDateTime[] createTime;

    @Schema(description = "取货层数")
    private Integer fromLocationStorey;
    @Schema(description = "放货层数")
    private Integer toLocationStorey;
    @Schema(description = "优先级")
    private Long priority;
    @Schema(description = "停车后是否锁定(0:否、1:是)")
    private Integer needLock;
    @Schema(description = "所选车辆电量(充电模式)")
    private Integer electricity;

    @Schema(description = "取货库位的排序")
    private Long fromLocationNumber;

    @Schema(description = "放货库位的排序")
    private Long toLocationNumber;

    @Schema(description = "取货库位ware_position_map_item的id")
    private Long fromMapItemId;

    @Schema(description = "放货库位ware_position_map_item的id")
    private Long toMapItemId;

    @Schema(description = "是否发生异常(0:正常、1：异常)")
    private Integer occurError;
}