package cn.iocoder.yudao.module.system.service.positionmap;

import cn.hutool.core.util.ObjectUtil;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.module.mqtt.api.path.dto.PositionAllChangePointBindingDTO;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.dto.PositionChangePointBindingDTO;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionChangePointBindingPageReqVO;
import cn.iocoder.yudao.module.system.controller.admin.positionmap.vo.PositionChangePointBindingSaveReqVO;
import cn.iocoder.yudao.module.system.dal.dataobject.positionmap.PositionChangePointBindingDO;
import cn.iocoder.yudao.module.system.dal.dataobject.positionmap.PositionMapDO;
import cn.iocoder.yudao.module.system.dal.mysql.positionmap.PositionChangePointBindingMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;


import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.*;

/**
 * 区域变更点绑定 Service 实现类
 *
 * @author 陈宾顺
 */
@Service
@Validated
public class PositionChangePointBindingServiceImpl extends ServiceImpl<PositionChangePointBindingMapper, PositionChangePointBindingDO> implements PositionChangePointBindingService {

    @Resource
    private PositionChangePointBindingMapper positionChangePointBindingMapper;

    @Override
    public Long createPositionChangePointBinding(PositionChangePointBindingSaveReqVO createReqVO) {
        // 插入
        PositionChangePointBindingDO positionChangePointBinding = BeanUtils.toBean(createReqVO, PositionChangePointBindingDO.class);
        positionChangePointBindingMapper.insert(positionChangePointBinding);
        // 返回
        return positionChangePointBinding.getId();
    }

    @Override
    public void updatePositionChangePointBinding(PositionChangePointBindingSaveReqVO updateReqVO) {
        // 校验存在
        validatePositionChangePointBindingExists(updateReqVO.getId());
        // 更新
        PositionChangePointBindingDO updateObj = BeanUtils.toBean(updateReqVO, PositionChangePointBindingDO.class);
        positionChangePointBindingMapper.updateById(updateObj);
    }

    @Override
    public void deletePositionChangePointBinding(Long id) {
        // 校验存在
        validatePositionChangePointBindingExists(id);
        // 删除
        positionChangePointBindingMapper.deleteById(id);
    }

    private void validatePositionChangePointBindingExists(Long id) {
        if (positionChangePointBindingMapper.selectById(id) == null) {
            throw exception(POSITION_CHANGE_POINT_BINDING_NOT_EXISTS);
        }
    }

    @Override
    public PositionChangePointBindingDTO getPositionChangePointBinding(Long mapItemId) {
        PositionChangePointBindingDTO positionChangePointBinding = new PositionChangePointBindingDTO();
        PositionChangePointBindingDO position = positionChangePointBindingMapper.selectOne(new LambdaQueryWrapperX<PositionChangePointBindingDO>()
                .eq(PositionChangePointBindingDO::getStartingPointId, mapItemId));
        if (ObjectUtil.isNotEmpty(position)) {
            positionChangePointBinding.setId(position.getId());
            positionChangePointBinding.setSortNum(position.getEndPointSortNum());
            positionChangePointBinding.setPointId(position.getEndPointId());
            return positionChangePointBinding;
        }

        PositionChangePointBindingDO startPosition = positionChangePointBindingMapper.selectOne(new LambdaQueryWrapperX<PositionChangePointBindingDO>()
                .eq(PositionChangePointBindingDO::getEndPointId, mapItemId));
        if (ObjectUtil.isNotEmpty(startPosition)) {
            positionChangePointBinding.setId(startPosition.getId());
            positionChangePointBinding.setSortNum(startPosition.getStartingPointSortNum());
            positionChangePointBinding.setPointId(startPosition.getStartingPointId());
        }

        return positionChangePointBinding;
    }

    @Override
    public PageResult<PositionChangePointBindingDO> getPositionChangePointBindingPage(PositionChangePointBindingPageReqVO pageReqVO) {
        return positionChangePointBindingMapper.selectPage(pageReqVO);
    }

    @Override
    public List<PositionAllChangePointBindingDTO> getAllPositionChangePointBinding() {
        return positionChangePointBindingMapper.getAllPositionChangePointBinding();
    }


}
